@@ -590,6 +590,9 @@ def workbook_to_json(
     survey_meta = []
 
     dynamic_default_warning_added = False
+
+    # row by row, validate questions, throwing errors and adding warnings
+    # where needed.
     for row in survey_sheet:
         row_number += 1
         if stack[-1] is not None:
@@ -825,7 +828,14 @@ def workbook_to_json(
                 raise PyXFormError(
                     row_format_string % row_number + " Missing calculation."
                 )
-
+        if question_type in constants.DEPRECATED_DEVICE_ID_METADATA_FIELDS:
+            warnings.append(
+                (row_format_string % row_number)
+                + " "
+                + question_type
+                + " is no longer supported on most devices. "
+                "Only old versions of Collect on Android versions older than 11 still support it."
+            )
         # Check if the question is actually a setting specified
         # on the survey sheet
         settings_type = aliases.settings_header.get(question_type)
@@ -1077,6 +1087,7 @@ def workbook_to_json(
                     list_name not in choices
                     and select_type != "select one external"
                     and file_extension not in [".csv", ".xml"]
+                    and not re.match(r"\$\{(.*?)\}", list_name)
                 ):
                     if not choices:
                         raise PyXFormError(
@@ -1185,7 +1196,9 @@ def workbook_to_json(
                 ):
                     new_json_dict["itemset"] = list_name
                     json_dict["choices"] = choices
-                elif file_extension in [".csv", ".xml"]:
+                elif file_extension in [".csv", ".xml"] or re.match(
+                    r"\$\{(.*?)\}", list_name
+                ):
                     new_json_dict["itemset"] = list_name
                 else:
                     new_json_dict["list_name"] = list_name
@@ -1270,6 +1283,25 @@ def workbook_to_json(
             parent_children_array.append(new_dict)
             continue
 
+        if question_type == "audio":
+            new_dict = row.copy()
+            parameters = get_parameters(row.get("parameters", ""), ["quality"])
+
+            if "quality" in parameters.keys():
+                if parameters["quality"] not in [
+                    "voice-only",
+                    "low",
+                    "normal",
+                    "external",
+                ]:
+                    raise PyXFormError("Invalid value for quality.")
+
+                new_dict["bind"] = new_dict.get("bind", {})
+                new_dict["bind"].update({"odk:quality": parameters["quality"]})
+
+            parent_children_array.append(new_dict)
+            continue
+
         # TODO: Consider adding some question_type validation here.
 
         # Put the row in the json dict as is:
